# ParGeo

Generate complex two-dimensional geometries, e.g. for the simulation of composite materials.



## Basic Usage

## Installation and Requirements

`pargeo 0.1.0.` requires:

- `Python >= 3.11`
- `Gmsh >= 4.11.1` [Optional, for mesh generation in .MSH format]

Install from PyPI:

```bash
pip install pargeo
``` 

To install in development mode, clone the repository and:
```bash
pip install -e .
```

## Contribute


## Cite